@@ -1,7 +1,14 @@
 import sys
 
 # https://stackoverflow.com/questions/32234156/how-to-unimport-a-python-module-which-is-already-imported
+#cheap hack to update frames
 def deimport(module_object=None,module=None,verbose=False):
+    try:
+        _deimport(module_object,module,verbose)
+    except:
+         _deimport(module_object,module,verbose)
+
+def _deimport(module_object=None,module=None,verbose=False):
     if module==None:
         module=module_object.__name__
     if verbose:
